##
##  gettext.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         gettext
Summary:      GNU National Language Support (NLS) Toolkit
URL:          http://www.gnu.org/software/gettext/
Vendor:       Free Software Foundation
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        BASE
Group:        Charset
License:      GPL
Version:      0.23
Release:      20241207

#   list of sources
Source0:      http://ftp.gnu.org/gnu/gettext/gettext-%{version}.tar.gz
Patch0:       gettext.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, gcc, make, automake
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  libiconv
PreReq:       libiconv

%description
    Gettext is the GNU toolkit for National Language Support (NLS).

%track
    prog gettext = {
        version   = %{version}
        url       = http://ftp.gnu.org/gnu/gettext/
        regex     = gettext-(__VER__)\.tar\.gz
    }

%prep
    %setup -q
    %patch -p0

%build
    #   strip Automake version numbers from binaries
    %{l_shtool} subst \
        -e 's;-${am__api_version};;g' \
        `find . -name configure -print`

    #   remove part that conflicts with libiconv
    %{l_shtool} subst \
        -e '/localcharset.\$lo/d' \
        gettext-runtime/intl/Makefile.in
    %{l_shtool} subst \
        -e 's;\(SUBDIRS.*=.*\)intl-java ;\1;' \
        -e 's;\(SUBDIRS.*=.*\)intl-csharp ;\1;' \
         gettext-runtime/Makefile.in
    %{l_shtool} subst \
        -e 's;^.*intl-java/Makefile.*$;;' \
        -e 's;^.*intl-csharp/Makefile.*$;;' \
        gettext-runtime/configure

    #   disable a few parts from building
    %{l_shtool} subst \
        -e 's;@BUILDJAVA@;no;g' \
        -e 's;@BUILDJAVAEXE@;no;g' \
        -e 's;@BUILDCSHARP@;no;g' \
        gettext-tools/src/Makefile.in
    %{l_shtool} subst \
        -e 's;^\(SUBDIRS =.*\)system-tests gnulib-tests examples;\1;' \
        gettext-tools/Makefile.in
    %{l_shtool} subst \
        -e 's;\#if USEJEXE;#ifdef USEJEXE;' \
        gettext-tools/src/read-java.c \
        gettext-tools/src/urlget.c

    #   configure toolkit
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags}" \
    GREP="grep" \
    ./configure \
        --prefix=%{l_prefix} \
        --datarootdir=%{l_prefix}/share \
        --mandir=%{l_prefix}/man \
        --infodir=%{l_prefix}/info \
        --with-libiconv-prefix=%{l_prefix} \
        --with-included-gettext \
        --without-libexpat-prefix \
        --disable-libasprintf \
        --disable-csharp \
        --disable-java \
        --disable-shared

    #   build toolkit
    %{l_make} %{l_mflags}

%install
    #   install toolkit
    %{l_make} %{l_mflags} install \
        AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT" \
        DESTDIR=$RPM_BUILD_ROOT

    #   strip down installation
    rm -f $RPM_BUILD_ROOT%{l_prefix}/info/dir
    rm -f $RPM_BUILD_ROOT%{l_prefix}/lib/charset.alias
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/share/gettext/projects
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/share/locale
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/share/doc
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/lib/xemacs
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* 2>/dev/null || true

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

